@@ -2,9 +2,7 @@
 #include <string>
 using namespace std;
 
-int read_dpkg(vector<string>& packages, vector<string>& db);
-int read_dpkg_header(vector<string>& packages);
-int read_dpkg_items(vector<string>& dpkg);
+int read_dpkg(vector<string>& packages, vector<string>& db, bool print_csv);
 
 struct Diversion{
         string oldfile;
