@@ -5,19 +5,10 @@
 #include <iostream>
 #include <fstream>
 #include <algorithm>
-
-#include "plocate.h"
-#include "python.h"
-
-#ifndef BUSTER
 #include <filesystem>
-namespace fs = std::filesystem;
-#else
-#include <experimental/filesystem>
-#include <experimental/string_view>
-using namespace std::experimental;
-namespace fs = std::experimental::filesystem;
-#endif
+
+#include "locate.h"
+#include "python.h"
 
 // build fail on hurd-i386
 #ifndef PATH_MAX
@@ -41,7 +32,7 @@ static void read_ignores(vector<string>& ignores, const string& ignore_path)
 	}
 }
 
-int read_plocate(vector<string>& fs, const string& ignore_path)
+int read_locate(vector<string>& fs, const string& ignore_path)
 {
 	bool debug=getenv("DEBUG") != nullptr;
 
@@ -61,15 +52,10 @@ int read_plocate(vector<string>& fs, const string& ignore_path)
 	if ((fp = popen("plocate /", "r")) == nullptr) return 1;
 	while (fgets(buf, sizeof(buf),fp))
 	{
-#ifndef BUSTER
 		auto len = strlen(buf);
 		if (len == 0)
 			continue;
 		string_view filename { buf, len - 1 };  // trim trailing newline
-#else
-		buf[strlen(buf)-1] = '\0';
-		string filename = buf;
-#endif
 		auto toplevel { filename.substr(0, filename.find('/', 1)) };
 		if (   toplevel == "/dev"
 		    or (toplevel == "/home" /* and dirname != "/home" */)
@@ -89,7 +75,7 @@ int read_plocate(vector<string>& fs, const string& ignore_path)
 			error_code ec;
 			if (filename.size() + 1 == it.size()
 			&& it.compare(0, filename.size(), filename) == 0
-			&& fs::is_directory(filename, ec)) {
+			&& filesystem::is_directory(filename, ec)) {
 				ignored = true;
 				break;
 			}
@@ -104,7 +90,7 @@ int read_plocate(vector<string>& fs, const string& ignore_path)
 	// default PRUNEPATH in /etc/updatedb.conf
 	fs.emplace_back("/var/spool");
 	try {
-		for (const auto& entry: filesystem::recursive_directory_iterator{"/var/spool", filesystem::directory_options::skip_permission_denied}) 
+		for (const auto& entry: filesystem::recursive_directory_iterator{"/var/spool", filesystem::directory_options::skip_permission_denied})
 		{
 			fs.emplace_back(entry.path());
 		}
